==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/vi/lang.php <==
<?php
/**
 * vietnamese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     James Do <jdo@myrealbox.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Biên soạn trang này';
$lang['btn_source'] = 'Xem mã nguồn';
$lang['btn_show']   = 'Xem trang';
$lang['btn_create'] = 'Tạo trang này';
$lang['btn_search'] = 'Tìm';
$lang['btn_save']   = 'Lưu';
$lang['btn_preview']= 'Duyệt trước';
$lang['btn_top']    = 'Trở lên trên';
$lang['btn_revs']   = 'Các phiên bản cũ';
$lang['btn_recent'] = 'Thay đổi gần đây';
$lang['btn_upload'] = 'Tải lên';
$lang['btn_cancel'] = 'Huỷ bỏ';
$lang['btn_index']  = 'Mục lục';
$lang['btn_secedit']= 'Biên soạn';
$lang['btn_login']  = 'Đăng nhập';
$lang['btn_logout'] = 'Thoát';
$lang['btn_admin']  = 'Quản lý';
$lang['btn_update'] = 'Cập nhật';
$lang['btn_delete'] = 'Xoá';

$lang['loggedinas'] = 'Username đang dùng';
$lang['user']       = 'Username';
$lang['pass']       = 'Password';
$lang['remember']   = 'Lưu username/password lại';
$lang['fullname']   = 'Họ và tên';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Đăng ký';
$lang['badlogin']   = 'Username hoặc password không đúng.';

$lang['regmissing'] = 'Bạn cần điền vào tất cả các trường';
$lang['reguexists'] = 'Bạn khác đã dùng username này rồi.';
$lang['regsuccess'] = 'Đã tạo username, và đã gởi password.';
$lang['regmailfail']= 'Không gởi password được. Xin bạn liên hệ với người quản lý.';
$lang['regbadmail'] = 'Email hình như không đúng. Xin bạn liên hệ với người quản lý.';
$lang['regpwmail']  = 'Password DokuWiki của bạn là';
$lang['reghere']    = 'Xin bạn đăng ký username nếu chưa có.';

$lang['txt_upload']   = 'Chọn tệp để tải lên';
$lang['txt_filename'] = 'Điền wikiname (tuỳ ý)';
$lang['lockedby']     = 'Đang khoá bởi';
$lang['lockexpire']   = 'Khoá sẽ hết hạn vào lúc';
$lang['willexpire']   = 'Khoá của bạn để biên soạn trang này sẽ hết hạn trong vòng 1 phút.\nĐể tránh xung đột, bạn nên bấm nút xem trước để lập lại thời gian khoá';

$lang['notsavedyet'] = 'Hiện có những thay đổi chưa được bảo lưu, và sẽ mất.\nBạn thật sự muốn tiếp tục?';
$lang['rssfailed']   = 'Rút nguồn này gặp phải lỗi';
$lang['nothingfound']= 'Không tìm được gì';

$lang['mediaselect'] = 'Chọn tệp media';
$lang['fileupload']  = 'Tải lên tệp media';
$lang['uploadsucc']  = 'Tải lên thành công';
$lang['uploadfail']  = 'Tải lên thất bại. Có thể vì không đủ phép?';
$lang['uploadwrong'] = 'Tải lên bị từ chối. Cấm tải loại tệp này';
$lang['namespaces']  = 'Đề tài';
$lang['mediafiles']  = 'Tệp có sẵn ở';

$lang['hits']       = 'Trùng';
$lang['quickhits']  = 'Trang trùng hợp';
$lang['toc']        = 'Nội dung';
$lang['current']    = 'hiện tại';
$lang['yours']      = 'Phiên bản hiện tại';
$lang['diff']       = 'cho xem khác biệt với phiên bản hiện tại';
$lang['line']       = 'Dòng';
$lang['breadcrumb'] = 'Trang đã xem';
$lang['lastmod']    = 'Thời điểm thay đổi';
$lang['by']         = 'do';
$lang['deleted']    = 'bị xoá';
$lang['created']    = 'được tạo ra';
$lang['restored']   = 'phiên bản cũ đã được khôi phục';
$lang['summary']    = 'Tóm tắt biên soạn';

$lang['mail_newpage'] = 'Trang được thêm:';
$lang['mail_changed'] = 'Trang thay đổi:';

$lang['js']['nosmblinks'] = "Nối với các Windows shares chỉ có hiệu lực với Microsoft Internet Explorer.\nBạn vẫn có thể sao và chép các mốc nối.";

$lang['qb_alert']   = 'Xin bạn điền đoạn văn để định dạng.\nĐoạn này sẽ được nối vào cuối văn kiện.';
$lang['qb_bold']    = 'Chữ đậm';
$lang['qb_italic']  = 'Chữ nghiêng';
$lang['qb_underl']  = 'Chữ gạch dưới';
$lang['qb_code']    = 'Chữ mã nguồn';
$lang['qb_h1']      = 'Đầu đề cấp 1';
$lang['qb_h2']      = 'Đầu đề cấp 2';
$lang['qb_h3']      = 'Đầu đề cấp 3';
$lang['qb_h4']      = 'Đầu đề cấp 4';
$lang['qb_h5']      = 'Đầu đề cấp 5';
$lang['qb_link']    = 'Mốc nối nội tại';
$lang['qb_extlink'] = 'Mốc nối ra ngoài';
$lang['qb_hr']      = 'Gạch ngang';
$lang['qb_ol']      = 'Điểm trong danh sách có thứ tự';
$lang['qb_ul']      = 'Điểm trong danh sách không đánh số';
$lang['qb_media']   = 'Thêm ảnh và tệp khác';
$lang['qb_sig']     = 'Đặt chữ ký';

$lang['del_confirm']= 'Xoá mục này?';


//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/inc/lang/vi/lang.php <==
<?php
/**
 * vietnamese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     James Do <jdo@myrealbox.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Biên soạn trang này';
$lang['btn_source'] = 'Xem mã nguồn';
$lang['btn_show']   = 'Xem trang';
$lang['btn_create'] = 'Tạo trang này';
$lang['btn_search'] = 'Tìm';
$lang['btn_save']   = 'Lưu';
$lang['btn_preview']= 'Duyệt trước';
$lang['btn_top']    = 'Trở lên trên';
$lang['btn_revs']   = 'Các phiên bản cũ';
$lang['btn_recent'] = 'Thay đổi gần đây';
$lang['btn_upload'] = 'Tải lên';
$lang['btn_cancel'] = 'Huỷ bỏ';
$lang['btn_index']  = 'Mục lục';
$lang['btn_secedit']= 'Biên soạn';
$lang['btn_login']  = 'Đăng nhập';
$lang['btn_logout'] = 'Thoát';
$lang['btn_admin']  = 'Quản lý';
$lang['btn_update'] = 'Cập nhật';
$lang['btn_delete'] = 'Xoá';
$lang['btn_register'] = 'Đăng ký';

$lang['loggedinas'] = 'Username đang dùng';
$lang['user']       = 'Username';
$lang['pass']       = 'Password';
$lang['remember']   = 'Lưu username/password lại';
$lang['fullname']   = 'Họ và tên';
$lang['email']      = 'E-Mail';
$lang['badlogin']   = 'Username hoặc password không đúng.';

$lang['regmissing'] = 'Bạn cần điền vào tất cả các trường';
$lang['reguexists'] = 'Bạn khác đã dùng username này rồi.';
$lang['regsuccess'] = 'Đã tạo username, và đã gởi password.';
$lang['regmailfail']= 'Không gởi password được. Xin bạn liên hệ với người quản lý.';
$lang['regbadmail'] = 'Email hình như không đúng. Xin bạn liên hệ với người quản lý.';
$lang['regpwmail']  = 'Password DokuWiki của bạn là';
$lang['reghere']    = 'Xin bạn đăng ký username nếu chưa có.';

$lang['txt_upload']   = 'Chọn tệp để tải lên';
$lang['txt_filename'] = 'Điền wikiname (tuỳ ý)';
$lang['lockedby']     = 'Đang khoá bởi';
$lang['lockexpire']   = 'Khoá sẽ hết hạn vào lúc';
$lang['js']['willexpire']   = 'Khoá của bạn để biên soạn trang này sẽ hết hạn trong vòng 1 phút.\nĐể tránh xung đột, bạn nên bấm nút xem trước để lập lại thời gian khoá';

$lang['js']['notsavedyet'] = "Hiện có những thay đổi chưa được bảo lưu, và sẽ mất.\nBạn thật sự muốn tiếp tục?";
$lang['rssfailed']   = 'Rút nguồn này gặp phải lỗi';
$lang['nothingfound']= 'Không tìm được gì';

$lang['mediaselect'] = 'Chọn tệp media';
$lang['fileupload']  = 'Tải lên tệp media';
$lang['uploadsucc']  = 'Tải lên thành công';
$lang['uploadfail']  = 'Tải lên thất bại. Có thể vì không đủ phép?';
$lang['uploadwrong'] = 'Tải lên bị từ chối. Cấm tải loại tệp này';
$lang['namespaces']  = 'Đề tài';
$lang['mediafiles']  = 'Tệp có sẵn ở';

$lang['hits']       = 'Trùng';
$lang['quickhits']  = 'Trang trùng hợp';
$lang['toc']        = 'Nội dung';
$lang['current']    = 'hiện tại';
$lang['yours']      = 'Phiên bản hiện tại';
$lang['diff']       = 'cho xem khác biệt với phiên bản hiện tại';
$lang['line']       = 'Dòng';
$lang['breadcrumb'] = 'Trang đã xem';
$lang['lastmod']    = 'Thời điểm thay đổi';
$lang['by']         = 'do';
$lang['deleted']    = 'bị xoá';
$lang['created']    = 'được tạo ra';
$lang['restored']   = 'phiên bản cũ đã được khôi phục';
$lang['summary']    = 'Tóm tắt biên soạn';

$lang['mail_newpage'] = 'Trang được thêm:';
$lang['mail_changed'] = 'Trang thay đổi:';

$lang['js']['nosmblinks'] = "Nối với các Windows shares chỉ có hiệu lực với Microsoft Internet Explorer.\nBạn vẫn có thể sao và chép các mốc nối.";

$lang['qb_bold']    = 'Chữ đậm';
$lang['qb_italic']  = 'Chữ nghiêng';
$lang['qb_underl']  = 'Chữ gạch dưới';
$lang['qb_code']    = 'Chữ mã nguồn';
$lang['qb_h1']      = 'Đầu đề cấp 1';
$lang['qb_h2']      = 'Đầu đề cấp 2';
$lang['qb_h3']      = 'Đầu đề cấp 3';
$lang['qb_h4']      = 'Đầu đề cấp 4';
$lang['qb_h5']      = 'Đầu đề cấp 5';
$lang['qb_link']    = 'Mốc nối nội tại';
$lang['qb_extlink'] = 'Mốc nối ra ngoài';
$lang['qb_hr']      = 'Gạch ngang';
$lang['qb_ol']      = 'Điểm trong danh sách có thứ tự';
$lang['qb_ul']      = 'Điểm trong danh sách không đánh số';
$lang['qb_media']   = 'Thêm ảnh và tệp khác';
$lang['qb_sig']     = 'Đặt chữ ký';

$lang['js']['del_confirm']= 'Xoá mục này?';


//Setup VIM: ex: et ts=2 :
